@@ -1,9 +1,10 @@
 ## File Name: mice_imputation_weighted_norm_draw.R
-## File Version: 0.08
+## File Version: 0.11
 
 #***** .weighted.norm.draw *******************
 mice_imputation_weighted_norm_draw <- function( yobs, xobs, ry, y, x,
-    weights.obs, ridge=.00001, ... ){
+    weights.obs, ridge=.00001, ... )
+{
     WW <- diag( weights.obs )
     # X'*W*X
     xtx <- t(xobs) %*% WW %*% xobs
@@ -19,8 +20,8 @@ mice_imputation_weighted_norm_draw <- function( yobs, xobs, ry, y, x,
     residuals2 <- weights.obs * residuals
     sigma.star <- sqrt(sum((residuals2)^2)/ stats::rchisq(1, sum(ry) - ncol(x)))
     beta.star <- coef + (t(chol((v + t(v))/2)) %*% stats::rnorm(ncol(x))) * sigma.star
-    parm <- list(coef, beta.star, sigma.star)
-    names(parm) <- c("coef","beta", "sigma")
+    #-- output
+    parm <- list( coef=coef, beta=beta.star, sigma=sigma.star)
     return(parm)
 }
 #----------------------------------------------------------------------
